import { ApiProperty } from '@nestjs/swagger';
import {
  Column,
  Entity,
  JoinColumn,
  ManyToOne,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { Group } from './group.entity';

@Entity('categories')
export class Category {
  // ----------------------------------------
  @ApiProperty({
    type: Number,
    name: 'id',
    description: 'id of category, auto-incremented',
    required: true,
  })
  @PrimaryGeneratedColumn('increment')
  id: number;

  // ----------------------------------------
  @ApiProperty({
    type: String,
    name: 'name',
    description: 'Category name',
    required: true,
  })
  @Column({
    type: 'varchar',
  })
  name: string;

  // ----------------------------------------
  @ApiProperty({
    type: Number,
    name: 'displayOrder',
    description: 'Display order',
    required: false,
  })
  @Column({
    type: 'tinyint',
    default: 0,
  })
  displayOrder: number;

  // ----------------------------------------
  @ApiProperty({
    name: 'group',
    description: 'Parent node: group',
    type: () => Group,
  })
  // @ApiPropertyOptional()
  @ManyToOne(() => Group, (group) => group.categories, {
    nullable: false,
    eager: true,
  })
  // @JoinColumn({ name: 'group_id', referencedColumnName: 'id' })
  @JoinColumn({ name: 'xref_group_id' })
  group: Group;
}
